==> integration-tests-jobs-service-springboot-1.8.0-20210628.060659-7-sources.jar: org/acme/travels/TimersModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "timers", name = "Timers", hidden = true)
public class TimersModelInput implements Model, MappableToModel<TimersModel> {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("delay", this.delay);
        return params;
    }

    @Override
    public TimersModelInput fromMap(Map<String, Object> params) {
        return fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public TimersModelInput fromMap(String id, Map<String, Object> params) {
        this.delay = (java.lang.String) params.get("delay");
        return this;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "delay")
    @javax.validation.Valid()
    private java.lang.String delay;

    public java.lang.String getDelay() {
        return delay;
    }

    public void setDelay(java.lang.String delay) {
        this.delay = delay;
    }

    @Override()
    public TimersModel toModel() {
        TimersModel result = new TimersModel();
        result.setDelay(getDelay());
        return result;
    }
}

==> integration-tests-jobs-service-springboot-3.0.0-20231201.044652-1-sources.jar: org/acme/travels/TimersModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;
import org.kie.kogito.ProcessInput;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "timers", name = "Timers", hidden = true)
@ProcessInput(processName = "timers")
public class TimersModelInput implements Model, MapInput, MapInputId, MapOutput, MappableToModel<TimersModel> {

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "delay")
    @jakarta.validation.Valid()
    private java.lang.String delay;

    public java.lang.String getDelay() {
        return delay;
    }

    public void setDelay(java.lang.String delay) {
        this.delay = delay;
    }

    @Override()
    public TimersModel toModel() {
        TimersModel result = new TimersModel();
        result.setDelay(getDelay());
        return result;
    }
}
